@@ -220,6 +220,7 @@ static void corosync_blackbox_write_to_file (void)
 
 	if ((res = qb_log_blackbox_write_to_file(fname)) < 0) {
 		LOGSYS_PERROR(-res, LOGSYS_LEVEL_ERROR, "Can't store blackbox file");
+		return ;
 	}
 	snprintf(fdata_fname, sizeof(fdata_fname), "%s/fdata", get_run_dir());
 	unlink(fdata_fname);
@@ -1064,7 +1065,7 @@ static enum e_corosync_done corosync_flock (const char *lockfile, pid_t pid)
 	lf = open (lockfile, O_WRONLY | O_CREAT, 0640);
 	if (lf == -1) {
 		log_printf (LOGSYS_LEVEL_ERROR, "Corosync Executive couldn't create lock file.");
-		return (COROSYNC_DONE_AQUIRE_LOCK);
+		return (COROSYNC_DONE_ACQUIRE_LOCK);
 	}
 
 retry_fcntl:
@@ -1086,7 +1087,7 @@ retry_fcntl:
 		default:
 			log_printf (LOGSYS_LEVEL_ERROR, "Corosync Executive couldn't acquire lock. Error was %s",
 			    strerror(errno));
-			err = COROSYNC_DONE_AQUIRE_LOCK;
+			err = COROSYNC_DONE_ACQUIRE_LOCK;
 			goto error_close;
 			break;
 		}
@@ -1095,7 +1096,7 @@ retry_fcntl:
 	if (ftruncate (lf, 0) == -1) {
 		log_printf (LOGSYS_LEVEL_ERROR, "Corosync Executive couldn't truncate lock file. Error was %s",
 		    strerror (errno));
-		err = COROSYNC_DONE_AQUIRE_LOCK;
+		err = COROSYNC_DONE_ACQUIRE_LOCK;
 		goto error_close_unlink;
 	}
 
@@ -1109,7 +1110,7 @@ retry_write:
 		} else {
 			log_printf (LOGSYS_LEVEL_ERROR, "Corosync Executive couldn't write pid to lock file. "
 				"Error was %s", strerror (errno));
-			err = COROSYNC_DONE_AQUIRE_LOCK;
+			err = COROSYNC_DONE_ACQUIRE_LOCK;
 			goto error_close_unlink;
 		}
 	}
@@ -1117,14 +1118,14 @@ retry_write:
 	if ((fd_flag = fcntl (lf, F_GETFD, 0)) == -1) {
 		log_printf (LOGSYS_LEVEL_ERROR, "Corosync Executive couldn't get close-on-exec flag from lock file. "
 			"Error was %s", strerror (errno));
-		err = COROSYNC_DONE_AQUIRE_LOCK;
+		err = COROSYNC_DONE_ACQUIRE_LOCK;
 		goto error_close_unlink;
 	}
 	fd_flag |= FD_CLOEXEC;
 	if (fcntl (lf, F_SETFD, fd_flag) == -1) {
 		log_printf (LOGSYS_LEVEL_ERROR, "Corosync Executive couldn't set close-on-exec flag to lock file. "
 			"Error was %s", strerror (errno));
-		err = COROSYNC_DONE_AQUIRE_LOCK;
+		err = COROSYNC_DONE_ACQUIRE_LOCK;
 		goto error_close_unlink;
 	}
 
@@ -1257,6 +1258,8 @@ int main (int argc, char **argv, char **envp)
 				} else if (strcmp(optarg, "min") == 0) {
 					prio = INT_MAX;
 				} else {
+					errno = 0;
+
 					tmpli = strtol(optarg, &ep, 10);
 					if (errno != 0 || *ep != '\0' || tmpli > INT_MAX || tmpli < INT_MIN) {
 						fprintf(stderr, "Priority value %s is invalid", optarg);
@@ -1459,7 +1462,13 @@ int main (int argc, char **argv, char **envp)
 	 * Now we are fully initialized.
 	 */
 	if (background) {
+		logsys_blackbox_prefork();
+
 		corosync_tty_detach ();
+
+		logsys_blackbox_postfork();
+
+		log_printf (LOGSYS_LEVEL_DEBUG, "Corosync TTY detached");
 	}
 
 	/*
