@@ -736,6 +736,11 @@ static int authenticate_nss_2_3 (
 		unsigned char	tmp_hash[hash_len[instance->crypto_hash_type]];
 		int             datalen = *buf_len - hash_len[instance->crypto_hash_type];
 
+		if (*buf_len <= hash_len[instance->crypto_hash_type]) {
+			log_printf(instance->log_level_security, "Received message is too short...  ignoring");
+			return -1;
+		}
+
 		if (calculate_nss_hash(instance, buf, datalen, tmp_hash) < 0) {
 			return -1;
 		}
@@ -803,6 +808,13 @@ size_t crypto_sec_header_size(
 	return hdr_size;
 }
 
+size_t crypto_get_current_sec_header_size(
+	const struct crypto_instance *instance)
+{
+
+	return (instance->crypto_header_size);
+}
+
 /*
  * 2.0 packet format:
  *   crypto_cipher_type | crypto_hash_type | __pad0 | __pad1 | hash | salt | data
@@ -844,10 +856,34 @@ int crypto_authenticate_and_decrypt (struct crypto_instance *instance,
 	int *buf_len)
 {
 	struct crypto_config_header *cch = (struct crypto_config_header *)buf;
+	const char *guessed_str;
+
+	if (*buf_len <= sizeof(struct crypto_config_header)) {
+		log_printf(instance->log_level_security, "Received message is too short...  ignoring");
+
+		return (-1);
+	}
 
 	if (cch->crypto_cipher_type != CRYPTO_CIPHER_TYPE_2_3) {
+		guessed_str = NULL;
+
+		if ((cch->crypto_cipher_type == 0xC0 && cch->crypto_hash_type == 0x70) ||
+		    (cch->crypto_cipher_type == 0x70 && cch->crypto_hash_type == 0xC0)) {
+			guessed_str = "Corosync 3.x";
+		} else if (cch->crypto_cipher_type == CRYPTO_CIPHER_TYPE_2_2) {
+			guessed_str = "Corosync 2.2";
+		} else if (cch->crypto_cipher_type == 0x01) {
+			guessed_str = "unencrypted Kronosnet";
+		} else if (cch->crypto_cipher_type >= 0 && cch->crypto_cipher_type <= 5) {
+			guessed_str = "unencrypted Corosync 2.0/2.1/1.x/OpenAIS";
+		} else {
+			guessed_str = "encrypted Kronosnet/Corosync 2.0/2.1/1.x/OpenAIS or unknown";
+		}
+
 		log_printf(instance->log_level_security,
-			   "Incoming packet has different crypto type. Rejecting");
+		   "Unsupported incoming packet (probably sent by %s). Rejecting",
+		   guessed_str);
+
 		return -1;
 	}
 
@@ -878,7 +914,6 @@ int crypto_authenticate_and_decrypt (struct crypto_instance *instance,
 	/*
 	 * decrypt
 	 */
-
 	if (decrypt_nss_2_3(instance, buf, buf_len) != 0) {
 		return -1;
 	}
