@@ -167,7 +167,6 @@ static void show_usage(const char *name)
 	printf("  -e <expected>  change expected votes for the cluster (*)\n");
 	printf("  -H             show nodeids in hexadecimal rather than decimal\n");
 	printf("  -i             show node IP addresses instead of the resolved name\n");
-	printf("  -p             when used with -s or -l, generates machine parsable output\n");
 	printf("  -o <a|n|i>     order by [a] IP address (default), [n] name, [i] nodeid\n");
 	printf("  -f             forcefully unregister a quorum device *DANGEROUS* (*)\n");
 	printf("  -h             show this help text\n");
@@ -519,7 +518,7 @@ static void display_nodes_data(nodeid_format_t nodeid_format, name_format_t name
 				if (info[i].flags & VOTEQUORUM_INFO_QDEVICE_REGISTERED) {
 					char buf[10];
 
-					snprintf(buf, sizeof(buf) - 1,
+					snprintf(buf, sizeof(buf),
 						 "%s,%s,%s",
 						 info[i].flags & VOTEQUORUM_INFO_QDEVICE_ALIVE?"A":"NA",
 						 info[i].flags & VOTEQUORUM_INFO_QDEVICE_CAST_VOTE?"V":"NV",
@@ -533,7 +532,9 @@ static void display_nodes_data(nodeid_format_t nodeid_format, name_format_t name
 		printf("%s", g_view_list[i].name);
 		if (g_view_list[i].node_id == our_nodeid) {
 			printf(" (local)");
-			our_flags = info[i].flags;
+			if (v_handle) {
+				our_flags = info[i].flags;
+			}
 		}
 		printf("\n");
 	}
